@@ -5,7 +5,7 @@
  * Massachusetts. 
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -294,6 +294,7 @@ typedef enum {
     VariantSuper,
     VariantGreat,
     VariantTwilight,
+    VariantMakruk,
     VariantUnknown       /* Catchall for other unknown variants */
 } VariantClass;
 
@@ -336,6 +337,7 @@ typedef enum {
   "super",\
   "great",\
   "twilight",\
+  "makruk",\
   "unknown" \
 }
 
