@@ -756,7 +756,7 @@ int GenLegal(board, flags, epfile, castlingRights, callback, closure)
      Board board;
      int flags;
      int epfile;
-     char castlingRights[];
+     signed char castlingRights[];
      MoveCallback callback;
      VOIDSTAR closure;
 {
@@ -1044,7 +1044,7 @@ ChessMove LegalityTest(board, flags, epfile, castlingRights, rf, ff, rt, ft, pro
      Board board;
      int flags, epfile;
      int rf, ff, rt, ft, promoChar;
-     char castlingRights[];
+     signed char castlingRights[];
 {
     LegalityTestClosure cl; ChessSquare piece = board[rf][ff];
     
@@ -1137,7 +1137,7 @@ void MateTestCallback(board, flags, kind, rf, ff, rt, ft, closure)
 int MateTest(board, flags, epfile, castlingRights)
      Board board;
      int flags, epfile;
-     char castlingRights[];
+     signed char castlingRights[];
 {
     MateTestClosure cl;
     int inCheck, r, f, myPieces=0, hisPieces=0, nrKing=0;
@@ -1260,7 +1260,7 @@ void Disambiguate(board, flags, epfile, closure)
                              closure->kind = c == '=' ? IllegalMove : WhitePromotionKnight;
                     else /* promotion optional, default is promote */
                              closure->kind = c == '=' ? NormalMove  : WhitePromotionQueen;
-                   
+                    if(c != '=') closure->promoCharIn = 'q';
                 } else closure->kind = (c == NULLCHAR || c == 'x' || c == '=') ?
                                             NormalMove : IllegalMove;
             } else {
@@ -1270,7 +1270,7 @@ void Disambiguate(board, flags, epfile, closure)
                              closure->kind = c == '=' ? IllegalMove : BlackPromotionKnight;
                     else /* promotion optional, default is promote */
                              closure->kind = c == '=' ? NormalMove  : BlackPromotionQueen;
-
+                    if(c != '=') closure->promoCharIn = 'q';
                 } else closure->kind = (c == NULLCHAR || c == 'x' || c == '=') ?
                                             NormalMove : IllegalMove;
             }
